@@ -1,13 +1,12 @@
-# $Id: Bitly.pm 106 2009-03-05 21:06:26Z pankaj $
+# $Id: Bitly.pm 77 2009-01-25 14:07:16Z pankaj $
 # $Author: pankaj $
-# $Date: 2009-03-06 02:36:26 +0530 (Fri, 06 Mar 2009) $
-# Author: <a href=mailto:pjain@cpan.org>Pankaj Jain</a>
+# $Date: 2009-01-25 19:37:16 +0530 (Sun, 25 Jan 2009) $
+# Author: <a href=mailto:perl@teknatus.com>Pankaj Jain</a>
 ################################################################################################################################
 package WWW::Shorten::Bitly;
 
 use warnings;
 use strict;
-use Carp;
 
 use base qw( WWW::Shorten::generic Exporter );
 
@@ -27,16 +26,16 @@ use vars qw( @ISA @EXPORT );
 
 =head1 NAME
 
-WWW::Shorten::Bitly - Interface to shortening URLs using L<http://bit.ly>
+WWW::Shorten::Bitly - Interface to shortening URLs using L<http:://bit.ly>
 
 =head1 VERSION
 
-$Revision: 106 $
+$Revision: 77 $
 
 =cut
 
 BEGIN {
-    our $VERSION = do { my @r = (0,q$Revision: 106 $ =~ /\d+/g); sprintf "%d."."%02d" x $#r, @r }; # must be all one line, for MakeMaker
+    our $VERSION = do { my @r = (0,q$Revision: 77 $ =~ /\d+/g); sprintf "%d."."%02d" x $#r, @r }; # must be all one line, for MakeMaker
     $WWW::Shorten::Bitly::VERBOSITY = 2;
 }
 
@@ -271,24 +270,6 @@ sub clicks {
     }
 }
 
-=head2 errors
-
-=cut
-
-sub errors {
-    my $self = shift;
-    my $base = "http://api.bit.ly/errors?version=2.0.1&login=" . $self->{USER} . "&apiKey=" . $self->{APIKEY};
-    $self->{response} = $self->{browser}->get($base);
-    $self->{$self->{bitlyurl}}->{content} = $self->{xml}->XMLin($self->{response}->{_content});
-    $self->{$self->{bitlyurl}}->{errorCode} = $self->{$self->{bitlyurl}}->{content}->{errorCode};
-    if ($self->{$self->{bitlyurl}}->{errorCode} == 0 ) {
-        $self->{$self->{bitlyurl}}->{clicks} = $self->{$self->{bitlyurl}}->{content}->{results};
-        return $self->{$self->{bitlyurl}}->{clicks};
-    } else {
-        return;
-    }
-}
-
 =head2 version
 
 Gets the module version number
@@ -304,7 +285,7 @@ sub version {
 
 =head1 AUTHOR
 
-Pankaj Jain, C<< <pjain at cpan.org> >>
+Pankaj Jain, C<< <perl at teknatus.com> >>
 
 =head1 BUGS
 
@@ -393,7 +374,7 @@ SUCH DAMAGES.
 
 =head1 SEE ALSO
 
-L<perl>, L<WWW::Shorten>, L<http://bit.ly>.
+L<perl>, L<WWW::Shorten>.
 
 =cut
 
